@@ -43,7 +43,7 @@ class SkelListRef(list):
 		:vartype cursor: str
 	"""
 
-	__slots__ = ["baseSkel", "getCursor", "customQueryInfo", "renderPreparation"]
+	__slots__ = ["baseSkel", "getCursor","get_orders", "customQueryInfo", "renderPreparation"]
 
 	def __init__(self, baseSkel=None):
 		"""
@@ -52,6 +52,7 @@ class SkelListRef(list):
 		super(SkelListRef, self).__init__()
 		self.baseSkel = baseSkel or {}
 		self.getCursor = lambda: None
+		self.get_orders = lambda: None
 		self.renderPreparation = None
 		self.customQueryInfo = {}
 
@@ -84,6 +85,9 @@ class Key:
 		"""
 		return self.id or self.name
 
+	def __str__(self):
+		return self.to_legacy_urlsafe().decode("ASCII")
+
 	def __repr__(self):
 		return "<viur.datastore.Key %s/%s, parent=%s>" % (self.kind, self.id_or_name, self.parent)
 
